==> virtualbox-sdk-6.1.30-1-x86_64.pkg.tar.zst: org/virtualbox_6_1/jaxws/IRecordingScreenSettingsGetVideoRateControlModeResponse.java <==

package org.virtualbox_6_1.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="returnval" type="{http://www.virtualbox.org/}RecordingVideoRateControlMode"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "returnval"
})
@XmlRootElement(name = "IRecordingScreenSettings_getVideoRateControlModeResponse")
public class IRecordingScreenSettingsGetVideoRateControlModeResponse {

    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected RecordingVideoRateControlMode returnval;

    /**
     * Gets the value of the returnval property.
     * 
     * @return
     *     possible object is
     *     {@link RecordingVideoRateControlMode }
     *     
     */
    public RecordingVideoRateControlMode getReturnval() {
        return returnval;
    }

    /**
     * Sets the value of the returnval property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecordingVideoRateControlMode }
     *     
     */
    public void setReturnval(RecordingVideoRateControlMode value) {
        this.returnval = value;
    }

}

==> virtualbox-sdk-7.0.10-2-x86_64.pkg.tar.zst: org/virtualbox_7_0/jaxws/IRecordingScreenSettingsGetVideoRateControlModeResponse.java <==

package org.virtualbox_7_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="returnval" type="{http://www.virtualbox.org/}RecordingRateControlMode"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "returnval"
})
@XmlRootElement(name = "IRecordingScreenSettings_getVideoRateControlModeResponse")
public class IRecordingScreenSettingsGetVideoRateControlModeResponse {

    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected RecordingRateControlMode returnval;

    /**
     * Gets the value of the returnval property.
     * 
     * @return
     *     possible object is
     *     {@link RecordingRateControlMode }
     *     
     */
    public RecordingRateControlMode getReturnval() {
        return returnval;
    }

    /**
     * Sets the value of the returnval property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecordingRateControlMode }
     *     
     */
    public void setReturnval(RecordingRateControlMode value) {
        this.returnval = value;
    }

}
